# Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#     * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


ifndef __WATCH_BUILD__
__WATCH_BUILD__ = 1


# Default rule
ifndef .DEFAULT_GOAL
.DEFAULT_GOAL = build
endif
.PHONY: build.default
build.default: $(.DEFAULT_GOAL) ;


# Includes
include _vars.mak


# Variables
PRODUCT ?= project
SRC_DIR ?= .
JAVA_FILES ?= $(wildcard $(SRC_DIR)/*.java)
JAVA_OBJS ?= $(patsubst $(SRC_DIR)/%.java,$(OUT_DIR)/%.class,$(JAVA_FILES))
JAVAC_OPTS ?= -Xlint:deprecation -target 1.5
ifdef _DEBUG
	JAVAC_OPTS += -g
endif
JAR_OBJ ?=
JAR_OPTS ?=
PROJECT_DEPS ?=
PROJ_CLEAN ?= $(JAVA_OBJS)


# Rules
.PHONY: build
build: dirs build.depends
ifneq ($(JAR_OBJ),)
build: $(JAR_OBJ)
else
build: build.java:
endif
build: ;

.PHONY: dirs
dirs:
	mkdir -p $(OUT_DIR)

ifneq ($(JAR_OBJ),)
$(JAR_OBJ): JAR_SRC_DIR = $(sort $(dir $(patsubst $(SRC_DIR)/%.java,$(OUT_DIR)/%.java,$(JAVA_FILES))))
$(JAR_OBJ): JAR_SRC_FILES = $(foreach a,$(JAR_SRC_DIR),$(a)/*.class)
$(JAR_OBJ): $(JAVA_FILES)
	javac $(JAVAC_OPTS) -d $(OUT_DIR) -classpath $(OUT_DIR) $(JAVA_FILES)
	cd $(OUT_DIR) && jar $(JAR_OPTS) -cf $(notdir $(WATCH_JAR)) $(patsubst $(OUT_DIR)/%,%,$(JAR_SRC_FILES))
else
.PHONY: build.java
build.java: $(JAVA_FILES)
	javac $(JAVAC_OPTS) -d $(OUT_DIR) -classpath $(OUT_DIR) $(JAVA_FILES)
endif

.PHONY: build.depends
build.depends:
	$(call MkDispatch, $(PROJECT_DEPS))


# Cleanup
.PHONY: clean
clean:
	$(call MkDispatch, $(PROJECT_DEPS), clean)
	rm -rf $(PROJ_CLEAN)


# Debug and help
include _help.mak

.PHONY: $(WATCH_DIR)/build/make/_build.help
help: $(WATCH_DIR)/build/make/_build.help
$(WATCH_DIR)/build/make/_build.help: ;
	$(call PrintHelp,   dirs,   Check intermediate directories)
	$(call PrintHelp,   build,  Build $(notdir $(PRODUCT)))
	$(call PrintHelp,   clean,  Clean $(notdir $(PRODUCT)) outputs)

.PHONY: $(WATCH_DIR)/build/make/_build.vars
vars: $(WATCH_DIR)/build/make/_build.vars
$(WATCH_DIR)/build/make/_build.vars:
	$(call ShowVariables,PRODUCT SRC_DIR JAVA_FILES JAVA_OBJS JAVAC_OPTS JAR_OBJ JAR_OPTS PROJECT_DEPS PROJ_CLEAN)


endif
# __WATCH_BUILD__
