# Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#     * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


ifndef __WATCH_UPDATE__
__WATCH_UPDATE__ = 1


# Default goal.
ifndef .DEFAULT_GOAL
.DEFAULT_GOAL = update
endif
.PHONY: update.default
update.default: $(.DEFAULT_GOAL)


include _vars.mak

RELEASE_DIR ?= release
XSL_FILES ?= $(patsubst $(WATCH_DIR)/xsl/%.xsl,$(RELEASE_DIR)/%.xsl,$(wildcard $(WATCH_DIR)/xsl/*.xsl))
PNG_FILES ?= $(patsubst $(WATCH_DIR)/xsl/ftvtree/%.png,$(RELEASE_DIR)/ftvtree/%.png,$(wildcard $(WATCH_DIR)/xsl/ftvtree/*.png))
TIMEPLOT_FILES ?= $(patsubst $(WATCH_DIR)/xsl/static.simile.mit.edu/%,$(RELEASE_DIR)/static.simile.mit.edu/%,$(shell find $(WATCH_DIR)/xsl/static.simile.mit.edu -type f | grep -v "/\.svn/"))
SCRIPT_FILES ?= $(patsubst $(WATCH_DIR)/scripts/%,$(RELEASE_DIR)/%,$(wildcard $(WATCH_DIR)/scripts/*.sh) $(wildcard $(WATCH_DIR)/scripts/*.bat))
IS_WATCH ?= $(words $(findstring watch.mak,$(MAKEFILE_LIST)))

.PHONY: update
update: update.dir
ifneq ($(IS_WATCH),1)
update: $(RELEASE_DIR)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX)
update: $(RELEASE_DIR)/cli.jar $(RELEASE_DIR)/jargs.jar $(RELEASE_DIR)/watch.jar
endif
update: update.resources


.PHONY: update.dir
update.dir:
	mkdir -p $(RELEASE_DIR)

.PHONY: update.resources
update.resources: $(XSL_FILES) $(PNG_FILES) $(TIMEPLOT_FILES) $(SCRIPT_FILES)

ifneq ($(IS_WATCH),1)
$(RELEASE_DIR)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX): $(RDX)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX)
	cp -f $< $@

$(RELEASE_DIR)/cli.jar: $(RDX)/cli.jar
	cp -f $< $@
	cd $(RELEASE_DIR) && jar -xf cli.jar

$(RELEASE_DIR)/jargs.jar: $(RDX)/jargs.jar
	cp -f $< $@
	cd $(RELEASE_DIR) && jar -xf jargs.jar

$(RELEASE_DIR)/watch.jar: $(RDX)/watch.jar
	cp -f $< $@
	cd $(RELEASE_DIR) && jar -xf watch.jar
endif

$(RELEASE_DIR)/static.simile.mit.edu/%: $(WATCH_DIR)/xsl/static.simile.mit.edu/%
	@mkdir -p $(dir $@)
	cp -f $< $@

$(RELEASE_DIR)/%.xsl: $(WATCH_DIR)/xsl/%.xsl
	cp -f $< $@

$(RELEASE_DIR)/ftvtree/%.png: $(WATCH_DIR)/xsl/ftvtree/%.png
	@mkdir -p $(dir $@)
	cp -f $< $@

$(RELEASE_DIR)/%: $(WATCH_DIR)/scripts/%
	cp -f $< $@ && chmod a+x $@


# Cleanup
.PHONY: update.clean
update.clean:
	@echo "Removing resources..."
	@rm -f $(XSL_FILES) $(PNG_FILES) $(TIMEPLOT_FILES) $(SCRIPT_FILES)
	@rm -rf $(sort $(dir $(PNG_FILES) $(TIMEPLOT_FILES)))
ifneq ($(IS_WATCH),1)
	rm -f $(RELEASE_DIR)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX)
	rm -rf $(RELEASE_DIR)/cli.jar $(RELEASE_DIR)/cli
	rm -rf $(RELEASE_DIR)/jargs.jar $(RELEASE_DIR)/jargs
	rm -rf $(RELEASE_DIR)/watch.jar $(RELEASE_DIR)/watch
endif


# Debug and help
include _help.mak

.PHONY: $(WATCH_DIR)/build/make/_update.help
help: $(WATCH_DIR)/build/make/_update.help
$(WATCH_DIR)/build/make/_update.help: ;
	$(call PrintHelp,   update, Update the release directory)
ifeq ($(.DEFAULT_GOAL),update)
	$(call PrintHelp,   clean,  Clean $(notdir $(PRODUCT)) outputs)
endif

.PHONY: $(WATCH_DIR)/build/make/_update.vars
vars: $(WATCH_DIR)/build/make/_update.vars
$(WATCH_DIR)/build/make/_update.vars:
	$(call ShowVariables,RELEASE_DIR XSL_FILES PNG_FILES TIMEPLOT_FILES SCRIPT_FILES IS_WATCH)


endif
# __WATCH_UPDATE__
