# Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#     * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# Default goal
.DEFAULT_GOAL = build
.PHONY: release.default
release.default: $(.DEFAULT_GOAL)


# Variables
include _vars.mak

RELEASE_VERSION = $(WATCH_VERSION)


# Includes
RELEASE_DIR = $(WATCH_DIR)/Watch_$(RELEASE_VERSION)
include _update.mak


# Rules
.PHONY: build
build: release.dep archive ;

.PHONY: archive
archive: release.clean update
ifeq ($(RELEASE_DIR),$(WATCH_DIR)/Watch_$(RELEASE_VERSION))
	cd $(dir $(RELEASE_DIR)) && tar cfz $(notdir $(RELEASE_DIR)).tgz $(notdir $(RELEASE_DIR))
else
	@# Do not create an archive if the release directory is not the basic release directory.
endif

.PHONY: release.dep
release.dep:
	$(call MkDispatch,watch.mak,)

.PHONY: deps
deps: ;

.PHONY: clean
clean: release.clean
	$(call MkDispatch,watch.mak,clean)

.PHONY: release.clean
release.clean:
	rm -rf $(RELEASE_DIR)
	rm -f $(RELEASE_DIR).tgz

# Debug and help
include _help.mak

.PHONY: $(WATCH_DIR)/build/make/release.help
help: $(WATCH_DIR)/build/make/release.help
$(WATCH_DIR)/build/make/release.help: ;
	$(call PrintHelp,   build,      Build the release and create the archive)
	$(call PrintHelp,   archive,    Create an archive of the release directory)
	$(call PrintHelp,   clean,      Clean the release outputs)

.PHONY: $(WATCH_DIR)/build/make/release.vars
vars: $(WATCH_DIR)/build/make/release.vars
$(WATCH_DIR)/build/make/release.vars:
	$(call ShowVariables,RELEASE_VERSION)
