# Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#     * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


.DEFAULT_GOAL = pre_build
.PHONY: watch.default
watch.default: $(.DEFAULT_GOAL) ;

# Variables
include _vars.mak
	# Build variables
PROJECT = watch
PROJECT_DEPS += $(CLI_DIR)/java/build/make/libclijava.mak
PROJECT_DEPS += $(CLI_DIR)/java/build/make/jni.mak
PROJECT_DEPS += $(CLI_DIR)/java/build/make/native.mak
CLI_DYN_LIB = $(RDX)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX)
CLI_JAR = $(RDX)/cli.jar
JARGS_JAR = $(RDX)/jargs.jar
WATCH_JAR = $(RDX)/watch.jar
JAVA_CLI_FILES = $(WATCH_DIR)/src/watch/WatchCli.java
JAVA_XMB_FILES = $(patsubst %.xmb,%.java,$(wildcard $(SRC_DIR)/watch/*.xmb))
JAVA_REG_FILES = $(filter-out $(JAVA_CLI_FILES) $(JAVA_XMB_FILES),$(wildcard $(SRC_DIR)/watch/*.java))
JAVA_FILES = $(JAVA_CLI_FILES) $(JAVA_XMB_FILES) $(JAVA_REG_FILES)
JAR_OBJ = $(WATCH_JAR)
PROJ_CLEAN += $(RDX)/cli $(CLI_JAR) $(CLI_DYN_LIB)
PROJ_CLEAN += $(RDX)/jargs $(JARGS_JAR)
PROJ_CLEAN += $(RDX)/watch $(WATCH_JAR)
PROJ_CLEAN += $(SRC_DIR)/watch/WatchCli.java
	# Update variables
RELEASE_DIR = $(OUT_DIR)


# Includes
include _build.mak
include _update.mak


# Rules
.PHONY: pre_build
pre_build: check_version build ;

.PHONY: check_version
check_version: VERSION_OK = $(shell \
	cat $(WATCH_DIR)/src/watch/Watch.java \
	| grep "public static final String VERSION = \"$(WATCH_VERSION)\"" \
	| wc -l \
)
check_version:
	@if [ "$(VERSION_OK)" != "1" ] ; then \
		echo "Updating Watch version in '$(WATCH_DIR)/src/watch/Watch.java'" ; \
		cat $(WATCH_DIR)/src/watch/Watch.java \
		| sed -e "s/public static final String VERSION = \".*\";/public static final String VERSION = \"$(WATCH_VERSION)\";/" > $(WATCH_DIR)/src/watch/Watch.java.tmp ; \
		mv $(WATCH_DIR)/src/watch/Watch.java.tmp $(WATCH_DIR)/src/watch/Watch.java ; \
	fi

$(CLI_DYN_LIB): $(CLI_DIR)/java/build/make/$(RDX)/$(DYN_LIB_PREFIX)cli$(DYN_LIB_SUFFIX)
	cp $< $@

$(CLI_JAR): $(CLI_DIR)/java/build/make/$(RDX)/cli.jar
	cp $< $@
	cd $(RDX) && jar -xf cli.jar

$(JARGS_JAR): $(WATCH_DIR)/jargs-1.0/lib/jargs.jar
	cp $< $@
	cd $(RDX) && jar -xf jargs.jar

$(WATCH_DIR)/jargs-1.0/lib/jargs.jar: $(WATCH_DIR)/jargs-1.0.tar.bz2
	cd $(WATCH_DIR) && tar xvfj jargs-1.0.tar.bz2 && cd build/make
	touch $@

$(OUT_DIR)/%.xsl: $(XSL_DIR)/%.xsl
	cp -f $< $@

$(SRC_DIR)/watch/WatchCli.java: $(SRC_DIR)/watch/WatchCli.xml $(CLI_DIR)/java/xsl/javaclic.xsl
	xsltproc --stringparam STR_CliClassName WatchCli $(CLI_DIR)/java/xsl/javaclic.xsl $< > $@

$(SRC_DIR)/watch/%.java: $(SRC_DIR)/watch/%.xmb $(XMB_DIR)/xmb2java.xsl
	rm -f $@.tmp
	head -n 27 ../../src/watch/Watch.java >> $@.tmp
	$(XMB_DIR)/xmb2java.sh $< $(patsubst %.java,%,$(notdir $@)) >> $@.tmp
	mv $@.tmp $@

.PHONY: deps
deps:
	$(call MkDispatch,$(CLI_DIR)/java/build/make/native.mak,deps)


# Debug and help
include _help.mak

.PHONY: $(WATCH_DIR)/build/make/watch.vars
vars: $(WATCH_DIR)/build/make/watch.vars
$(WATCH_DIR)/build/make/watch.vars: ;
	$(call ShowVariables, CLI_DYN_LIB CLI_JAR JARGS_JAR WATCH_JAR JAVA_CLI_FILES JAVA_XMB_FILES JAVA_REG_FILES)


# Dependencies
include $(AUTO_DEPS_FILE)
build: check_version $(CLI_DYN_LIB) $(CLI_JAR) $(JARGS_JAR) $(WATCH_JAR) update
clean: update.clean
