/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Watch class overriding for CLI to XML watch syntax translation.
    The CLI events normally sent to the Watch class are caught by this Cli2Xml class and redirected to a XmlInput instance instead. */
public class Cli2Xml extends Watch {

    /** Specific Cli2Xml application argments. */
    private static class Cli2XmlArgs extends Args {
        public Cli2XmlArgs() {
            super("Cli2Xml", "Cli to XML Watch files translator");
            setRemainingArgsDescription("[input files ...] [output file]", "[input files ...] [output file]: List of files terminated by the output file");
        }
        public void parse(String[] ARJ_Args) {
            super.parse(ARJ_Args);
            if (getOutputFile() == null) {
                printUsage();
                System.exit(2);
            }
        }
        public String getOutputFile() {
            if (super.getInputFiles().size()  > 0) {
                return super.getInputFiles().lastElement();
            } else {
                return null;
            }
        }
        public java.util.Vector<String> getInputFiles() {
            java.util.Vector<String> j_Vector = new java.util.Vector<String>(super.getInputFiles());
            if (j_Vector.size() > 0) {
                j_Vector.remove(j_Vector.size() - 1);
            }
            return j_Vector;
        }
    }

    /** Main function of the application.
        Analyze arguments and launches the CLI.
        @param ARJ_Args Arguments passed to the program. */
    public static void main(String[] ARJ_Args) {
        try {

            cli.Cli.load();

            Cli2XmlArgs w_Args = new Cli2XmlArgs();
            w_Args.parse(ARJ_Args);

            if (w_Args.getOutputFile() != null) {
                Traces.traceApp("Cli2Xml(): j_OutputFile = " + w_Args.getOutputFile());

                run(new Cli2Xml(w_Args.getOutputFile()), w_Args);

                if (! ((Cli2Xml) m_wInstance).getbResult()) {
                    System.exit(-1);
                }
            }

        } catch (Exception e) {
            Display.printStackTrace(e);
        }
    }

    private final XmlInput_1_0 m_wWatchXml;
    private final String m_jOutputFile;
    private String m_jUserName;
    private String m_jCurrentDate;
    private boolean m_bResult;

    /** Constructor.
        @param J_OutputFile XML watch syntax output file path. */
    public Cli2Xml(String J_OutputFile) {
        m_wWatchXml = new XmlInput_1_0();
        m_jOutputFile = J_OutputFile;
        m_jUserName = null;
        m_jCurrentDate = null;
        m_bResult = true;

        // First of all, delete the output file.
        new java.io.File(m_jOutputFile).delete();
    }

    /** Result accessor.
        @return The result status. */
    public boolean getbResult() {
        return m_bResult;
    }

    /** No XML watch syntax file loading. Disabling of Watch.load().
        @param J_XmlPath Path of an XML watch syntax file. */
    public void load(String J_XmlPath) {
        // Do not load the file.
    }

    /** Comment input.
        @param J_Words Collection of words, making a sentence. */
    public void comment(java.util.Collection<String> J_Words) {
        /*if (J_Words != null) {
            String j_Comment = new String();
            for (java.util.Iterator<String> it = J_Words.iterator(); it.hasNext(); ) {
                String j_Word = it.next();
                if (j_Word != null) {
                    if (j_Comment.length() > 0) {
                        j_Comment += " ";
                    }
                    j_Comment += j_Word;
                } else {
                    onError("Cli2Xml.comment(): Invalid word. Ignoring word.");
                }
            }
            if (! m_wWatchXml.comment(j_Comment)) {
                onError("Cli2Xml.comment(): Command failed.");
            }
        } else {
            onError("Cli2Xml.comment(): Invalid parameters. Ignoring comment.");
        }*/
    }

    /** Project name declaration.
        @param J_ProjectName New project name. */
    public void projectName(String J_ProjectName) {
        if (J_ProjectName != null) {
            if (! m_wWatchXml.projectName(J_ProjectName)) {
                onError("Cli2Xml.projectName(): Command failed.");
            }
        } else {
            onError("Cli2Xml.projectName(): Invalid parameters. Ignoring project name.");
        }
    }

    /** Locale declaration.
        @param J_Locale New locale in its string form.
        @see watch.Watch#locale */
    public void locale(String J_Locale) {
        // First of all, call the parent class so that to take in account the locale settings.
        super.locale(J_Locale);

        if (J_Locale != null) {
            m_wWatchXml.locale(J_Locale);
        } else {
            onError("Cli2Xml.locale(): Invalid parameters. Ignoring locale.");
        }
    }

    /** Beginning of a task group.
        @param J_TaskId Task identifier.
        @param J_StartDate Task start date. */
    public void beginTaskGroup(String J_TaskId, String J_StartDate) {
        if (J_TaskId != null) {
            if ((J_StartDate != null) && new Date(J_StartDate).equals(Date.zero())) {
                onError("Cli2Xml.beginTaskGroup(): Invalid date " + J_StartDate);
            } else {
                if (! m_wWatchXml.beginTaskGroup(J_TaskId, J_StartDate)) {
                    onError("Cli2Xml.beginTaskGroup(): Command failed.");
                }
            }
        } else {
            onError("Cli2Xml.beginTaskGroup(): Invalid parameters. Ignoring task group.");
        }
    }

    /** End of a task group. */
    public void endTaskGroup() {
        if (! m_wWatchXml.endTaskGroup()) {
            onError("Cli2Xml.endTaskGroup(): Command failed.");
        }
    }

    /** Single task definition.
        @param J_TaskId                 Task identifier.
        @param J_ReferenceStartDate     Reference start date. Can be null if no specific reference start date.
        @param D_Reference              Reference value for the task. -1.0 if this task should not be checked against its reference.
        @param D_ReferenceRisks         Reference risks of the task.
        @param D_ReferenceOpportunities Reference opportunities of the task.
        @param J_PlannedStartDate       Planned start date. Can be null if no planification is done.
        @param J_PlannedEndDate         Planned end date. Can be null if no planification is done.
        @param E_SchedulingMode         Scheduling mode. Either Task.SCHEDULING_NONE, Task.SCHEDULING_AT_END or Task.SCHEDULING_LINEAR. */
    public void singleTask(
            String J_TaskId,
            String J_ReferenceStartDate, double D_Reference, double D_ReferenceRisks, double D_ReferenceOpportunities,
            String J_PlannedStartDate, String J_PlannedEndDate, int E_SchedulingMode) {
        if (J_TaskId != null) {
            if ((J_ReferenceStartDate != null) && new Date(J_ReferenceStartDate).equals(Date.zero())) {
                onError("Cli2Xml.singleTask(): Invalid date " + J_ReferenceStartDate);
            } else if ((J_PlannedStartDate != null) && new Date(J_PlannedStartDate).equals(Date.zero())) {
                onError("Cli2Xml.singleTask(): Invalid date " + J_PlannedStartDate);
            } else if ((J_PlannedEndDate != null) && new Date(J_PlannedEndDate).equals(Date.zero())) {
                onError("Cli2Xml.singleTask(): Invalid date " + J_PlannedEndDate);
            } else {
                if (! m_wWatchXml.singleTask(
                        J_TaskId,
                        J_ReferenceStartDate, D_Reference, D_ReferenceRisks, D_ReferenceOpportunities,
                        J_PlannedStartDate, J_PlannedEndDate, E_SchedulingMode)) {
                    onError("Cli2Xml.singleTask(): Command failed.");
                }
            }
        } else {
            onError("Cli2Xml.singleTask(): Invalid parameters. Ignoring task.");
        }
    }

    /** Current user setting. Useful for imputations for instance.
        @param J_UserName User identifier. */
    public void setCurrentUser(String J_UserName) {
        if (J_UserName != null) {
            m_jUserName = J_UserName;
        } else {
            onError("Cli2Xml.setCurrentUser(): Invalid parameters. Ignoring user.");
            m_jUserName = null;
        }
    }

    /** Imputation.
        @param J_TaskId Identifier of the task the imputation is related to.
        @param J_Date Date of the imputation.
        @param D_Imputed Imputation value. */
    public void imputation(String J_TaskId, String J_Date, double D_Imputed) {
        if ((m_jUserName != null) && (J_TaskId != null) && (J_Date != null)) {
            if (new Date(J_Date).equals(Date.zero())) {
                onError("Cli2Xml.imputation(): Invalid date " + J_Date);
            } else {
                if (! m_wWatchXml.imputation(m_jUserName, J_TaskId, J_Date, D_Imputed)) {
                    onError("Cli2Xml.imputation(): Command failed.");
                }
            }
        } else {
            onError("Cli2Xml.imputation(): Invalid parameters. Ignoring imputation.");
        }
    }

    /** Current revision date setting.
        @param J_Date Revision date to remember for next revisions and lock operations. */
    public void setCurrentRevisionDate(String J_Date) {
        m_jCurrentDate = J_Date;
    }

    /** Revision.
        @param J_TaskId Identifier of the task wich remaining value is being revised.
        @param J_Date Date of the revision.
        @param D_Remaining Revision of the remaining value.
        @param D_Risks Revision of the risks value.
        @param D_Opportunities Revision of the opportunities value.
        @param D_Earned Revision of the earned value. */
    public void revision(String J_TaskId, String J_Date, double D_Remaining, double D_Risks, double D_Opportunities, double D_Earned) {
        // Determine the revision date.
        String j_RevisionDate = m_jCurrentDate;
        if (J_Date != null) {
            j_RevisionDate = J_Date;
        }

        if ((J_TaskId != null) && (j_RevisionDate != null)) {
            if (new Date(j_RevisionDate).equals(Date.zero())) {
                onError("Cli2Xml.revision(): Invalid date " + j_RevisionDate);
            } else {
                if (! m_wWatchXml.revision(J_TaskId, j_RevisionDate, D_Remaining, D_Risks, D_Opportunities, D_Earned)) {
                    onError("Cli2Xml.revision(): Command failed.");
                }
            }
        } else {
            onError("Cli2Xml.revision(): Invalid parameters. Ignoring revision.");
        }
    }

    /** Lock operation.
        @param J_TaskId Identifier of the task being locked.
        @param J_Date Date of the lock operation. */
    public void lock(String J_TaskId, String J_Date) {
        // Determine the revision date.
        String j_LockDate = m_jCurrentDate;
        if (J_Date != null) {
            j_LockDate = J_Date;
        }

        if ((J_TaskId != null) && (j_LockDate != null)) {
            if (new Date(j_LockDate).equals(Date.zero())) {
                onError("Cli2Xml.lock(): Invalid date " + j_LockDate);
            } else {
                if (! m_wWatchXml.lock(J_TaskId, j_LockDate)) {
                    onError("Cli2Xml.lock(): Command failed.");
                }
            }
        } else {
            onError("Cli2Xml.lock(): Invalid parameters. Ignoring lock operation.");
        }
    }

    /** No executions. Disabling of Watch.execute().
        @param J_FocusTask Task to focus the computation onto.
        @param J_Users List of users to focus the computation onto.
        @param J_ReferenceDate Date to consider as the reference date.
        @param J_StartDate Date to start the computation from.
        @param J_EndDate Date to end the computation at.
        @param B_SumImputationsOnly When true, limits the computation at summing imputations.
        @param B_History When true, launches the history computation instead of a regular computation.
        @param W_Transformation Output transformation.
        @param J_OutputFileName Results output file name. */
    public void execute(
            String J_FocusTask, java.util.Collection<String> J_Users,
            String J_ReferenceDate, String J_StartDate, String J_EndDate,
            boolean B_SumImputationsOnly, boolean B_History,
            Transformation W_Transformation,
            String J_OutputFileName) {
        // Do nothing.
    }

    /** CLI error handler. Permits the translation to fail if a CLI syntax error has been detected.
        @param location CLI error location information.
        @param message CLI error message. */
    public void onError(cli.ResourceString location, cli.ResourceString message) {
        onError(null);
    }

    /** CLI exit handler. Automatic output XML watch syntax file generation if sucessful until there. */
    public void onExit() {
        if (m_bResult) {
            if (m_jOutputFile != null) {
                if (! m_wWatchXml.writeFile(m_jOutputFile)) {
                    onError("Cli2Xml.onExit(): Could not write file '" + m_jOutputFile + "'.");
                }
            } else {
                onError("Cli2Xml.onExit(): Invalid parameters. Could not write file.");
            }
        }
    }

    private void onError(String J_ErrorMessage) {
        m_bResult = false;
        if (J_ErrorMessage != null) {
            Display.error(J_ErrorMessage);
        }
        cli.Shell cli_Shell = getShell();
        if (cli_Shell != null) {
            // This should terminate the CLI execution.
            cli_Shell.quit();
        }
    }

}
