/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Display toolkit class.
    Provides static methods for displaying information. */
class Display {

    // Output.
    /** CLI output device accessor.
        @return CLI output device. */
    public static cli.OutputDevice out() {
        cli.Shell cli_Shell = Watch.getShell();
        if (cli_Shell != null) {
            cli.OutputDevice cli_Out = cli_Shell.getStream(cli.Shell.OUTPUT_STREAM);
            if (cli_Out != null) {
                return cli_Out;
            }
        }

        return cli.OutputDevice.getStdOut();
    }

    /** CLI error device accessor.
        @return CLI error device. */
    public static cli.OutputDevice err() {
        cli.Shell cli_Shell = Watch.getShell();
        if (cli_Shell != null) {
            cli.OutputDevice cli_Out = cli_Shell.getStream(cli.Shell.ERROR_STREAM);
            if (cli_Out != null) {
                return cli_Out;
            }
        }

        return cli.OutputDevice.getStdErr();
    }
    /** Display the stack trace of an exception.
        Same as Exception.printStackTrace(), but directing the output to the CLI error device.
        @param e Exception to print stack trace of. */
    public static void printStackTrace(Exception e) {
        Display.err().printStackTrace(e);
    }

    // Warnings.
    private static boolean m_bShowWarnings = true;

    /** Show warning configuration.
        @param B_ShowWarnings true if the warnings should be displayed, false if not. */
    public static void showWarnings(boolean B_ShowWarnings) {
        m_bShowWarnings = B_ShowWarnings;
    }

    /** Display a warning.
        Displays the warning only if the warning configuration permits it.
        @param J_Warning Warning message to display. */
    public static void warn(String J_Warning) {
        if (m_bShowWarnings) {
            err().put("!!!Warning!!! " + J_Warning).endl();
        }
    }

    /** Display an error.
        @param J_Error Error message to display. */
    public static void error(String J_Error) {
        err().put("!!!Error!!! " + J_Error).endl();
    }

}
