/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Watch imputation files editor. */
public class Editor {

    /** Main function. */
    public static void main(String ARJ_Args[]) {
        try {

            cli.Cli.load();

            // Parse arguments.
            Editor.getInstance().getArgs().parse(ARJ_Args);

            // Load default or specific configuration file.
            Editor.getInstance().getConfigFile().load(Editor.getInstance().getArgs().getConfigFile());

            // Additional project files.
            for (java.util.Iterator<String> j_ProjectIt = Editor.getInstance().getArgs().getProjectFiles().iterator(); j_ProjectIt.hasNext(); ) {
                String j_ProjectFile = j_ProjectIt.next();
                if (j_ProjectFile != null) {
                    Editor.getInstance().getConfigFile().getProjects().add(j_ProjectFile);
                    Editor.getInstance().getConfigFile().setChanged();
                }
            }

            // Load project files.
            Editor.getInstance().reloadProjects();

            // Load input files.
            Editor.getInstance().getArgs().setUniqueInputFile(null);
            java.util.Collection<String> j_InputFiles = Editor.getInstance().getArgs().getInputFiles();
            if (j_InputFiles.size() > 0) {
                for (java.util.Iterator<String> j_InputFileIt = j_InputFiles.iterator(); j_InputFileIt.hasNext(); ) {
                    String j_InputFile = j_InputFileIt.next();
                    Editor.getInstance().loadInputFile(j_InputFile);
                }
            } else {
                // No input file.
                // Let's try to load the last input file.
                if (Editor.getInstance().getConfigFile().getCurrentInputFile() != null) {
                    Editor.getInstance().loadInputFile(Editor.getInstance().getConfigFile().getCurrentInputFile());
                }
            }

            // Let the frame...
            Editor.getInstance().getMainFrame().loadComplete();
        } catch (Exception e) {
            Display.printStackTrace(e);
        }
    }

    /** Singleton. */
    public static Editor getInstance() {
        if (m_wInstance == null) { m_wInstance = new Editor(); }
        return m_wInstance;
    }
    private static Editor m_wInstance = null;


    /* Members. */
    private final EditorArgs m_wArgs;
    private final EditorConfigFile m_wConfigFile;
    private final Task m_wMainTask;
    private final EditorMainFrame m_wMainFrame;

    /** Constructor. */
    private Editor() {
        m_wArgs = new EditorArgs();
        m_wConfigFile = new EditorConfigFile();
        m_wMainTask = new Task("main", null, 0.0, 0.0, 0.0, null, null, Task.SCHEDULING_NONE);
        m_wMainFrame = new EditorMainFrame();
    }

    /** Arguments accessor. */
    public EditorArgs getArgs() {
        return m_wArgs;
    }

    /** Configuration file accessor. */
    public EditorConfigFile getConfigFile() {
        return m_wConfigFile;
    }

    /** Project reloading. */
    public void reloadProjects() {
        java.util.SortedSet<String> j_Errors = new java.util.TreeSet<String>();
        for (java.util.Iterator<String> j_It = getConfigFile().getProjects().iterator(); j_It.hasNext(); ) {
            String j_ProjectFile = j_It.next();
            if (j_ProjectFile != null) {
                try {
                    new XmlInput_1_0().xml2model(new java.io.File(j_ProjectFile), new EditorInput());
                } catch (Exception e) {
                    Display.printStackTrace(e);
                    j_Errors.add(j_ProjectFile);
                }
            }
        }
        for (java.util.Iterator<String> j_ErrorIt = j_Errors.iterator(); j_ErrorIt.hasNext(); ) {
            Editor.getInstance().getConfigFile().getProjects().remove(j_ErrorIt.next());
            Editor.getInstance().getConfigFile().setChanged();
        }
    }

    /** Task addition. */
    public void addTask(Task W_Task) {
        m_wMainTask.addSubTask(W_Task);
    }

    /** Tasks accessors. */
    public java.util.Iterator<Task> getTaskIterator() {
        return m_wMainTask.getSubTaskIterator();
    }

    /** Task reference values accessors. */
    public double getTaskReference(String J_TaskId) {
        Task w_Task = m_wMainTask.findTask(J_TaskId);
        if (w_Task != null) { return w_Task.getReference(); }
        return -1.0;
    }

    /** Input file loading. */
    public void loadInputFile(String J_InputFile) {
        J_InputFile = J_InputFile.replace('\\', '/');
        m_wArgs.setUniqueInputFile(J_InputFile);
        EditorInput.run(new EditorInput(), m_wArgs);
        m_wArgs.setUniqueInputFile(null);
    }

    /** File saving. */
    public void save(String J_OutputFile) {
        XmlInput_1_0 w_OutputFile = new XmlInput_1_0();
        for (java.util.Iterator<EditorDayPanel> j_DayIt = getMainFrame().getDays().iterator(); j_DayIt.hasNext(); ) {
            EditorDayPanel w_Day = j_DayIt.next();
            if (w_Day != null) {
                for (java.util.Iterator<EditorImputationPanel> j_ImputationIt = w_Day.getImputations().iterator(); j_ImputationIt.hasNext(); ) {
                    EditorImputationPanel w_Imputation = j_ImputationIt.next();
                    if (w_Imputation != null) {
                        if ((w_Imputation.getImputed() != 0.0) || (w_Imputation.getComment() != null)) {
                            String j_UserName = getMainFrame().getSafeUserName();
                            w_OutputFile.imputation(j_UserName, w_Imputation.getTaskId(), w_Day.getDate().toString(), w_Imputation.getImputed());
                            if (w_Imputation.getComment() != null) {
                                w_OutputFile.comment(w_Imputation.getComment());
                            }
                        }
                        if (w_Imputation.isLocked()) {
                            w_OutputFile.lock(w_Imputation.getTaskId(), w_Day.getDate().toString());
                        } else if ((w_Imputation.getRemaining() != -1.0)
                                    || (w_Imputation.getRisks() != -1.0)
                                    || (w_Imputation.getOpportunities() != -1.0)
                                    || (w_Imputation.getEarned() != -1.0)) {
                            w_OutputFile.revision(
                                w_Imputation.getTaskId(), w_Day.getDate().toString(),
                                w_Imputation.getRemaining(),
                                w_Imputation.getRisks(), w_Imputation.getOpportunities(),
                                w_Imputation.getEarned()
                            );
                        }
                    }
                }
            }
        }
        try {
            w_OutputFile.model2xml(new java.io.File(J_OutputFile), new EditorInput());
        } catch (Exception e) {
            Display.printStackTrace(e);
        }
    }

    /** Main frame accessor. */
    public EditorMainFrame getMainFrame() {
        return m_wMainFrame;
    }

}
