/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Watch Editor command line arguments processing. */
class EditorArgs extends Args {

    private Option m_wConfigFile;
    private Option m_wTasks;
    private String m_jInputFile;

    /** Constructor. */
    public EditorArgs() {
        super("WatchEditor", "Watch imputation files editor");
        m_wConfigFile = addStringOption('c', "config", "[{-c,--config} path]", "-c,--config: Non default configuration file");
        m_wTasks = addStringOption('p', "project", "[{-p,--project} path1,path2]", "-p,--project: Project file containing task definitions (coma separated)");
        m_jInputFile = null;
    }

    /** Configuration file accessor.
        @return The configuration file path. */
    public String getConfigFile() {
        String j_ConfigFile = m_wConfigFile.getstrValue();
        if (j_ConfigFile == null) {
            j_ConfigFile = EditorConfigFile.getDefaultPath();
        }
        return j_ConfigFile;
    }

    /** Project files accessor.
        @return List of project paths. */
    public java.util.Vector<String> getProjectFiles() {
        java.util.Vector<String> j_Vector = new java.util.Vector<String>();
        if (m_wTasks.getstrValue() != null) {
            String[] arj_ProjectFiles = m_wTasks.getstrValue().split(",");
            if (arj_ProjectFiles != null) {
                for (int i=0; i<arj_ProjectFiles.length; i++) {
                    j_Vector.add(arj_ProjectFiles[i]);
                }
            }
        }
        return j_Vector;
    }

    /** Unique input file setting.
        Used for loading a single input file.
        @param J_InputFile Unique input file path. Unique input file feature off when null. */
    public void setUniqueInputFile(String J_InputFile) {
        m_jInputFile = J_InputFile;
    }

    /** Input files accessor.
        When the unique input file is set, only this element is returned.
        @return Input files list. */
    public java.util.Vector<String> getInputFiles() {
        if (m_jInputFile == null) {
            return super.getInputFiles();
        } else {
            java.util.Vector<String> j_Vector = new java.util.Vector<String>();
            j_Vector.add(m_jInputFile);
            return j_Vector;
        }
    }

}

