/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Day panel class. */
class EditorDayPanel extends javax.swing.JPanel {

    /** Constructor.
        @param W_Date Initial date attached to the day panel. */
    public EditorDayPanel(Date W_Date) {
        setBackground(EditorMainFrame.COLOR_BACKGROUND);

        setLayout(new javax.swing.BoxLayout(this, javax.swing.BoxLayout.PAGE_AXIS));

        add(new HeaderPanel(W_Date));
    }

    /** Date accessor.
        @return Date of the day panel. */
    public Date getDate() {
        for (int i=0; i<getComponentCount(); i++) {
            if (getComponent(i) instanceof HeaderPanel) {
                return ((HeaderPanel) getComponent(i)).getDate();
            }
        }
        return null;
    }

    /** Command for updating the sum of imputations of the day. */
    public void updateSumOfTheDay() {
        double d_SumOfTheDay = 0.0;
        for (java.util.Iterator<EditorImputationPanel> j_It = getImputations().iterator(); j_It.hasNext(); ) {
            EditorImputationPanel w_Imputation = j_It.next();
            if (w_Imputation != null) {
                d_SumOfTheDay += w_Imputation.getImputed();
            }
        }
        d_SumOfTheDay = ((double) Math.round(d_SumOfTheDay * 100.0)) / 100.0;

        for (int i=0; i<getComponentCount(); i++) {
            if (getComponent(i) instanceof HeaderPanel) {
                ((HeaderPanel) getComponent(i)).setSumOfTheDay(d_SumOfTheDay);
                break;
            }
        }
    }

    /** Imputation panels accessor.
        @return List of imputation panels of the day panel. */
    public java.util.Collection<EditorImputationPanel> getImputations() {
        java.util.Collection<EditorImputationPanel> j_Imputations = new java.util.Vector<EditorImputationPanel>();
        for (int i=0; i<getComponentCount(); i++) {
            java.awt.Component awt_Component = getComponent(i);
            if (awt_Component instanceof EditorImputationPanel) {
                j_Imputations.add((EditorImputationPanel) awt_Component);
            }
        }
        return j_Imputations;
    }
    /** Specific task imputation panel accessor. Creates a new imputation penl if not found.
        @param J_TaskId Task identifier of the imputation searched.
        @return The existing imputation panel if found, a new one otherwise. */
    public EditorImputationPanel getImputation(String J_TaskId) {
        EditorImputationPanel w_Imputation = null;

        for (java.util.Iterator<EditorImputationPanel> j_It = getImputations().iterator(); j_It.hasNext(); ) {
            w_Imputation = j_It.next();
            if (w_Imputation != null) {
                if (w_Imputation.getTaskId().equals(J_TaskId)) {
                    return w_Imputation;
                }
            }
        }

        w_Imputation = new EditorImputationPanel(J_TaskId);
        add(w_Imputation);
        validate();
        w_Imputation.scrollRectToVisible(w_Imputation.getBounds());

        return w_Imputation;
    }


    /** Inner class for headers of day panels. */
    private class HeaderPanel extends javax.swing.JPanel {
        private javax.swing.JTextField m_swDate;
        private javax.swing.JLabel m_swSum;

        /** Constructor.
            @param W_Date Initial date of the day panel. */
        public HeaderPanel(Date W_Date) {
            setBackground(EditorMainFrame.COLOR_DAY_TITLE);

            javax.swing.SpringLayout sw_Layout = new javax.swing.SpringLayout();
            setLayout(sw_Layout);

            javax.swing.JLabel sw_DateLabel = new javax.swing.JLabel(">> Date:");
            add(sw_DateLabel);

            String j_Date = "";
            if (W_Date != null) {
                j_Date = W_Date.toString();
            }
            m_swDate = new javax.swing.JTextField(j_Date);
            EditorMainFrame.configureTextField(m_swDate, EditorMainFrame.DAY_WIDTH);
            add(m_swDate);
            m_swDate.getDocument().addDocumentListener(new DayActionListener());

            javax.swing.JLabel sw_TotalLabel = new javax.swing.JLabel("Total:");
            add(sw_TotalLabel);

            m_swSum = new javax.swing.JLabel("0.0");
            add(m_swSum);

            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_DateLabel, 5, javax.swing.SpringLayout.WEST, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_DateLabel, 10, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swDate, 5, javax.swing.SpringLayout.EAST, sw_DateLabel);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swDate, 10, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_TotalLabel, 10, javax.swing.SpringLayout.EAST, m_swDate);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_TotalLabel, 10, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swSum, 5, javax.swing.SpringLayout.EAST, sw_TotalLabel);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swSum, 10, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, this, 10, javax.swing.SpringLayout.SOUTH, m_swSum);
        }

        /** Date accessor.
            @return The date of the day panel. */
        public Date getDate() {
            String j_Date = m_swDate.getText();
            if ((j_Date == null) || (j_Date.length() <= 0)) {
                return null;
            } else {
                return new Date(j_Date);
            }
        }

        /** Sum of imputations setting.
            @param D_SumOfTheDay Sum of imputations of the day. */
        public void setSumOfTheDay(double D_SumOfTheDay) {
            m_swSum.setText(new Double(D_SumOfTheDay).toString());
        }


        /** Inner class for change detections on the date field. */
        private class DayActionListener implements javax.swing.event.DocumentListener {
            public void changedUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
            public void insertUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
            public void removeUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
            private void onChange() {
                Editor.getInstance().getMainFrame().setChanged();
            }
        }
    }


}

