/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Imputation panel class. */
class EditorImputationPanel extends javax.swing.JPanel {
    /** Task name component member. */
    private javax.swing.JComboBox m_swTaskName;
    /** Imputed value component member. */
    private javax.swing.JTextField m_swImputed;
    /** Lock status component member. */
    private javax.swing.JCheckBox m_swLock;
    /** Remaining value component member. */
    private javax.swing.JTextField m_swRemaining;
    /** Risks value component member. */
    private javax.swing.JTextField m_swRisks;
    /** Opportunities value component member. */
    private javax.swing.JTextField m_swOpportunities;
    /** Earned value component member. */
    private javax.swing.JTextField m_swEarned;
    /** Comments component member. */
    private javax.swing.JTextArea m_swComment;


    /** Constructor.
        @param J_TaskId Initial task identifier of the imputation panel. */
    public EditorImputationPanel(String J_TaskId) {
        setBackground(EditorMainFrame.COLOR_BACKGROUND);

        javax.swing.SpringLayout sw_Layout = new javax.swing.SpringLayout();
        setLayout(sw_Layout);

        m_swTaskName = new javax.swing.JComboBox();
        m_swTaskName.setEditable(true);
        if (J_TaskId != null) { m_swTaskName.setSelectedItem(J_TaskId); }
        int i_Height = new javax.swing.JTextField().getSize().height;
        m_swTaskName.setSize(new java.awt.Dimension(300, i_Height));
        m_swTaskName.setMinimumSize(new java.awt.Dimension(m_swTaskName.getMinimumSize().width, i_Height));
        m_swTaskName.setMaximumSize(new java.awt.Dimension(m_swTaskName.getMaximumSize().width, i_Height));
        m_swTaskName.setBackground(EditorMainFrame.COLOR_BACKGROUND);
        add(m_swTaskName);
        m_swTaskName.addPopupMenuListener(new TaskNamePopupActionListener());
        try {
            ((javax.swing.text.JTextComponent) m_swTaskName.getEditor().getEditorComponent()).getDocument().addDocumentListener(new TextFieldActionListener());
        } catch (Exception e) {
            e.printStackTrace();
        }
        m_swTaskName.getEditor().getEditorComponent().addMouseListener(new PopupMenuListener());

        m_swImputed = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swImputed, EditorMainFrame.NUMBER_WIDTH);
        add(m_swImputed);
        m_swImputed.getDocument().addDocumentListener(new SumActionListener());
        m_swImputed.addMouseListener(new PopupMenuListener());

        m_swLock = new javax.swing.JCheckBox("Lock");
        m_swLock.setBackground(EditorMainFrame.COLOR_BACKGROUND);
        add(m_swLock);
        m_swLock.addActionListener(new LockActionListener());
        m_swLock.addMouseListener(new PopupMenuListener());

        m_swRemaining = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swRemaining, EditorMainFrame.NUMBER_WIDTH);
        add(m_swRemaining);
        m_swRemaining.getDocument().addDocumentListener(new TextFieldActionListener());
        m_swRemaining.addMouseListener(new PopupMenuListener());

        m_swRisks = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swRisks, EditorMainFrame.NUMBER_WIDTH);
        add(m_swRisks);
        m_swRisks.getDocument().addDocumentListener(new TextFieldActionListener());
        m_swRisks.addMouseListener(new PopupMenuListener());

        m_swOpportunities = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swOpportunities, EditorMainFrame.NUMBER_WIDTH);
        add(m_swOpportunities);
        m_swOpportunities.getDocument().addDocumentListener(new TextFieldActionListener());
        m_swOpportunities.addMouseListener(new PopupMenuListener());

        m_swEarned = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swEarned, EditorMainFrame.NUMBER_WIDTH);
        add(m_swEarned);
        m_swEarned.getDocument().addDocumentListener(new TextFieldActionListener());
        m_swEarned.addMouseListener(new PopupMenuListener());

        m_swComment = new javax.swing.JTextArea();
        m_swComment.setBorder(m_swImputed.getBorder());
        add(m_swComment);
        m_swComment.getDocument().addDocumentListener(new TextFieldActionListener());
        m_swComment.addMouseListener(new PopupMenuListener());

        sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swTaskName, 15, javax.swing.SpringLayout.WEST, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swTaskName, 0, javax.swing.SpringLayout.NORTH, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swComment, 30, javax.swing.SpringLayout.WEST, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swComment, 0, javax.swing.SpringLayout.SOUTH, m_swTaskName);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, this, 5, javax.swing.SpringLayout.EAST, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, this, 5, javax.swing.SpringLayout.SOUTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swEarned, 0, javax.swing.SpringLayout.EAST, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swEarned, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swOpportunities, -5, javax.swing.SpringLayout.WEST, m_swEarned);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swOpportunities, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swRisks, -5, javax.swing.SpringLayout.WEST, m_swOpportunities);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swRisks, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swRemaining, -5, javax.swing.SpringLayout.WEST, m_swRisks);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swRemaining, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swLock, -5, javax.swing.SpringLayout.WEST, m_swRemaining);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swLock, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swImputed, -5, javax.swing.SpringLayout.WEST, m_swLock);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, m_swImputed, 0, javax.swing.SpringLayout.NORTH, m_swComment);
        sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, m_swTaskName, -5, javax.swing.SpringLayout.WEST, m_swImputed);
        sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swTaskName, 15, javax.swing.SpringLayout.WEST, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swTaskName, 0, javax.swing.SpringLayout.NORTH, this);

        this.addMouseListener(new PopupMenuListener());
    }

    /** Parent day panel accessor.
        @return The parent day panel. null if not found. */
    public EditorDayPanel getDayPanel() {
        for (java.awt.Component awt_Parent = getParent(); (awt_Parent != null); awt_Parent = awt_Parent.getParent()) {
            if (awt_Parent instanceof EditorDayPanel) {
                return (EditorDayPanel) awt_Parent;
            }
        }
        return null;
    }

    /** Task identifier accessor.
        @return The task identifier contained in the field component. */
    public String getTaskId() { return (String) m_swTaskName.getSelectedItem(); }
    /** Imputed value setting.
        Updates the sum of the day of the parent day panel.
        @param D_Imputed New imputed value. */
    public void setImputed(double D_Imputed) { setValue(m_swImputed, D_Imputed); getDayPanel().updateSumOfTheDay(); }
    /** Imputed value accessor.
        @return Imputed value contained in the field component. */
    public double getImputed() { return getValue(m_swImputed, 0.0); }
    /** Lock status setting. */
    public void setLocked() { m_swLock.setSelected(true); updateLockStatus(); }
    /** Lock status accessor. */
    public boolean isLocked() { return m_swLock.isSelected(); }
    /** Remaining value setting.
        @param D_Remaining New remaining value. */
    public void setRemaining(double D_Remaining) { setValue(m_swRemaining, D_Remaining); }
    /** Remaining value accessor.
        @return Remaining value contained in the field component. */
    public double getRemaining() { return getValue(m_swRemaining, -1.0); }
    /** Risks value setting.
        @param D_Risks new risks value. */
    public void setRisks(double D_Risks) { setValue(m_swRisks, D_Risks); }
    /** Risks value accessor.
        @return Risks value contained in the field component. */
    public double getRisks() { return getValue(m_swRisks, -1.0); }
    /** Opportunities value setting.
        @param D_Opportunities New opportunities value. */
    public void setOpportunities(double D_Opportunities) { setValue(m_swOpportunities, D_Opportunities); }
    /** Opportunities value accessor.
        @return The opportunities value contained in the field component. */
    public double getOpportunities() { return getValue(m_swOpportunities, -1.0); }
    /** Earned value setting.
        @param D_Earned New earned value setting. */
    public void setEarned(double D_Earned) { setValue(m_swEarned, D_Earned); }
    /** Earned value accessor.
        @return Earned value containde in the field component. */
    public double getEarned() { return getValue(m_swEarned, -1.0); }
    /** Generic value setting for any field component.
        @param SW_TextField Field component.
        @param D_Value new value. */
    private void setValue(javax.swing.JTextField SW_TextField, double D_Value) {
        SW_TextField.setText(new Double(D_Value).toString());
        Editor.getInstance().getMainFrame().setChanged();
    }
    /** Generic value accessor.
        @param SW_TextField Field component to retrieve the value of.
        @param D_Default Default value if the field component has no valid value.
        @return The value contained in the field component. The default value if no valid value. */
    private double getValue(javax.swing.JTextField SW_TextField, double D_Default) { try { return new Double(SW_TextField.getText()); } catch (Exception e) { return D_Default; } }
    /** Comment addition.
        @param J_Comment Imputation comment to add. */
    public void addComment(String J_Comment) {
        if (getComment() != null) {
            m_swComment.setText(m_swComment.getText() + "\r\n" + J_Comment);
            m_swComment.scrollRectToVisible(m_swComment.getBounds());
        } else {
            m_swComment.setText(J_Comment);
        }
        Editor.getInstance().getMainFrame().setChanged();
    }
    /** Comment accessor.
        @return All comments attached to the imputation as a single string. */
    public String getComment() {
        if ((m_swComment.getText() != null) && (m_swComment.getText().length() > 0)) {
            return m_swComment.getText();
        } else {
            return null;
        }
    }

    /** Command for updating the lock status.
        Components are disabled, earned value is set... */
    private void updateLockStatus() {
        if (isLocked()) {
            setValue(m_swRemaining, 0.0); m_swRemaining.setEditable(false);
            setValue(m_swRisks, 0.0); m_swRisks.setEditable(false);
            setValue(m_swOpportunities, 0.0); m_swOpportunities.setEditable(false);
            setValue(m_swEarned, Editor.getInstance().getTaskReference(getTaskId())); m_swEarned.setEditable(false);
        } else {
            m_swRemaining.setText(""); m_swRemaining.setEditable(true);
            m_swRisks.setText(""); m_swRisks.setEditable(true);
            m_swOpportunities.setText(""); m_swOpportunities.setEditable(true);
            m_swEarned.setText(""); m_swEarned.setEditable(true);
        }
    }

    /** Inner class for combo box menu management. */
    private class TaskNamePopupActionListener implements javax.swing.event.PopupMenuListener {
        private String m_jInitialSelectedItem;
        public void popupMenuCanceled(javax.swing.event.PopupMenuEvent sw_Event) {
            if (sw_Event.getSource() instanceof javax.swing.JComboBox) {
                javax.swing.JComboBox sw_ComboBox = (javax.swing.JComboBox) sw_Event.getSource();
                if ((m_jInitialSelectedItem == null) && (sw_ComboBox.getSelectedItem() != null)) {
                    Editor.getInstance().getMainFrame().setChanged();
                } else if ((m_jInitialSelectedItem != null)
                        && (sw_ComboBox.getSelectedItem() != null)
                        && (! m_jInitialSelectedItem.equals(sw_ComboBox.getSelectedItem()))) {
                    Editor.getInstance().getMainFrame().setChanged();
                }
            }
        }
        public void popupMenuWillBecomeInvisible(javax.swing.event.PopupMenuEvent sw_Event) {
        }
        public void popupMenuWillBecomeVisible(javax.swing.event.PopupMenuEvent sw_Event) {
            if (sw_Event.getSource() instanceof javax.swing.JComboBox) {
                javax.swing.JComboBox sw_ComboBox = (javax.swing.JComboBox) sw_Event.getSource();
                m_jInitialSelectedItem = (String) sw_ComboBox.getSelectedItem();
                boolean b_InitialChanged = Editor.getInstance().getMainFrame().getbChanged();
                sw_ComboBox.removeAllItems();
                for (java.util.Iterator<Task> j_TaskIt = Editor.getInstance().getTaskIterator(); j_TaskIt.hasNext(); ) {
                    sw_ComboBox.addItem(j_TaskIt.next().getId());
                }
                if (m_jInitialSelectedItem != null) {
                    sw_ComboBox.setSelectedItem(m_jInitialSelectedItem);
                }
                if (b_InitialChanged) { Editor.getInstance().getMainFrame().setChanged(); }
                else { Editor.getInstance().getMainFrame().setUnchanged(); }
            }
        }
    }
    /** Inner class for imputed value field components events management.
        Automatically updates the sum of imputations of the day.
        Notifies content has changed. */
    private class SumActionListener implements javax.swing.event.DocumentListener {
        private boolean m_bUpdateScheduled;
        public void changedUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void insertUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void removeUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        private void onChange() {
            Editor.getInstance().getMainFrame().setChanged();

            if (! m_bUpdateScheduled) {
                m_bUpdateScheduled = true;
                new javax.swing.Timer(200, new java.awt.event.ActionListener() { public void actionPerformed(java.awt.event.ActionEvent evt) {
                    doUpdate();
                }}).start();
            }
        }
        private void doUpdate() {
            m_bUpdateScheduled = false;
            if (getDayPanel() != null) {
                getDayPanel().updateSumOfTheDay();
            }
        }
    }
    /** Field components events management.
        Notifies content has changed. */
    private class TextFieldActionListener implements javax.swing.event.DocumentListener {
        private boolean m_bUpdateScheduled;
        public void changedUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void insertUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void removeUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        private void onChange() {
            Editor.getInstance().getMainFrame().setChanged();
        }
    }
    /** Lock status component events management.
        Notifies content has changed. */
    private class LockActionListener implements java.awt.event.ActionListener {
        public void actionPerformed(java.awt.event.ActionEvent awt_Event) {
            Editor.getInstance().getMainFrame().setChanged();
            updateLockStatus();
        }
    }
    /** Context menus management. */
    private class PopupMenuListener extends java.awt.event.MouseAdapter {
        public void mouseReleased(java.awt.event.MouseEvent AWT_Event) {
            /*if (AWT_Event.isPopupTrigger()) {
                javax.swing.JPopupMenu sw_Menu = new javax.swing.JPopupMenu();
                javax.swing.JMenuItem sw_Item = sw_Menu.add(new javax.swing.JMenuItem("Add comment"));
                sw_Menu.show(AWT_Event.getComponent(), AWT_Event.getX(), AWT_Event.getY());
                // javax.swing.ImageIcon
            }*/
        }
    }


    /** Imputations header panel.
        Only one instance at the top of the main frame. */
    public static class HeaderPanel extends javax.swing.JPanel {
        /** Constructor. */
        public HeaderPanel() {
            setBackground(EditorMainFrame.COLOR_HEADER_BACKGROUND);

            javax.swing.SpringLayout sw_Layout = new javax.swing.SpringLayout();
            setLayout(sw_Layout);

            javax.swing.JTextField sw_TaskName = new javax.swing.JTextField("Imputation / revision task name");
            int i_Height = new javax.swing.JTextField().getSize().height;
            sw_TaskName.setSize(new java.awt.Dimension(300, i_Height));
            sw_TaskName.setMinimumSize(new java.awt.Dimension(sw_TaskName.getMinimumSize().width, i_Height));
            sw_TaskName.setMaximumSize(new java.awt.Dimension(sw_TaskName.getMaximumSize().width, i_Height));
            sw_TaskName.setEditable(false);
            sw_TaskName.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_TaskName);

            javax.swing.JTextField sw_Imputed = new javax.swing.JTextField("Imputed");
            EditorMainFrame.configureTextField(sw_Imputed, EditorMainFrame.NUMBER_WIDTH);
            sw_Imputed.setEditable(false);
            sw_Imputed.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Imputed);

            javax.swing.JTextField sw_Lock = new javax.swing.JTextField("Lock");
            EditorMainFrame.configureTextField(sw_Lock, EditorMainFrame.LOCK_WIDTH);
            sw_Lock.setEditable(false);
            sw_Lock.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Lock);

            javax.swing.JTextField sw_Remaining = new javax.swing.JTextField("Remaining");
            EditorMainFrame.configureTextField(sw_Remaining, EditorMainFrame.NUMBER_WIDTH);
            sw_Remaining.setEditable(false);
            sw_Remaining.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Remaining);

            javax.swing.JTextField sw_Risks = new javax.swing.JTextField("Risks");
            EditorMainFrame.configureTextField(sw_Risks, EditorMainFrame.NUMBER_WIDTH);
            sw_Risks.setEditable(false);
            sw_Risks.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Risks);

            javax.swing.JTextField sw_Opportunities = new javax.swing.JTextField("Opportunities");
            EditorMainFrame.configureTextField(sw_Opportunities, EditorMainFrame.NUMBER_WIDTH);
            sw_Opportunities.setEditable(false);
            sw_Opportunities.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Opportunities);

            javax.swing.JTextField sw_Earned = new javax.swing.JTextField("Earned");
            EditorMainFrame.configureTextField(sw_Earned, EditorMainFrame.NUMBER_WIDTH);
            sw_Earned.setEditable(false);
            sw_Earned.setBackground(EditorMainFrame.COLOR_HEADER_FOREGROUND);
            add(sw_Earned);

            javax.swing.JTextField sw_Scroll = new javax.swing.JTextField();
            EditorMainFrame.configureTextField(sw_Scroll, EditorMainFrame.SCROLL_WIDTH);
            sw_Scroll.setEditable(false);
            sw_Scroll.setBackground(EditorMainFrame.COLOR_HEADER_BACKGROUND);
            add(sw_Scroll);

            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_TaskName, 5, javax.swing.SpringLayout.WEST, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_TaskName, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Imputed, 5, javax.swing.SpringLayout.EAST, sw_TaskName);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Imputed, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Lock, 5, javax.swing.SpringLayout.EAST, sw_Imputed);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Lock, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Remaining, 5, javax.swing.SpringLayout.EAST, sw_Lock);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Remaining, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Risks, 5, javax.swing.SpringLayout.EAST, sw_Remaining);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Risks, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Opportunities, 5, javax.swing.SpringLayout.EAST, sw_Risks);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Opportunities, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Earned, 5, javax.swing.SpringLayout.EAST, sw_Opportunities);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Earned, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Scroll, 5, javax.swing.SpringLayout.EAST, sw_Earned);
            sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Scroll, 5, javax.swing.SpringLayout.NORTH, this);
            sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, this, 0, javax.swing.SpringLayout.EAST, sw_Scroll);
            sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, this, 5, javax.swing.SpringLayout.SOUTH, sw_Scroll);
        }
    }


}

