/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** User panel class. */
class EditorUserPanel extends javax.swing.JPanel {
    /** User name component member. */
    private javax.swing.JTextField m_swUserName;

    /** Constructor. */
    public EditorUserPanel() {
        setBackground(EditorMainFrame.COLOR_HEADER_BACKGROUND);

        javax.swing.SpringLayout sw_Layout = new javax.swing.SpringLayout();
        setLayout(sw_Layout);

        javax.swing.JLabel sw_Label = new javax.swing.JLabel("User:");
        add(sw_Label);

        m_swUserName = new javax.swing.JTextField();
        EditorMainFrame.configureTextField(m_swUserName, EditorMainFrame.USER_WIDTH);
        add(m_swUserName);
        m_swUserName.getDocument().addDocumentListener(new UserActionListener());

        sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, sw_Label, 5, javax.swing.SpringLayout.WEST, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, sw_Label, 5, javax.swing.SpringLayout.NORTH, this);
        sw_Layout.putConstraint(javax.swing.SpringLayout.WEST, m_swUserName, 5, javax.swing.SpringLayout.EAST, sw_Label);
        sw_Layout.putConstraint(javax.swing.SpringLayout.NORTH, m_swUserName, 5, javax.swing.SpringLayout.NORTH, this);
        //sw_Layout.putConstraint(javax.swing.SpringLayout.EAST, this, 5, javax.swing.SpringLayout.EAST, m_swUserName);
        sw_Layout.putConstraint(javax.swing.SpringLayout.SOUTH, this, 5, javax.swing.SpringLayout.SOUTH, m_swUserName);
    }

    /** User name accessor.
        @return The user name contained in the field component, null if not set. */
    public String getUserName() {
        if ((m_swUserName.getText() == null) || (m_swUserName.getText().length() <= 0)) {
            return null;
        } else {
            return m_swUserName.getText();
        }
    }
    /** Safe user name accessor.
        @return The user name contained in the field component, an empty string if not set. */
    public String getSafeUserName() {
        if (m_swUserName.getText() == null) {
            return new String();
        } else {
            return m_swUserName.getText();
        }
    }
    /** User name setting.
        Notify the document as changed is needed.
        @param J_UserName New user name. null to reset the current user name. */
    public void setUserName(String J_UserName) {
        if (J_UserName != null) {
            if ((m_swUserName.getText() == null) || (! m_swUserName.getText().equals(J_UserName))) {
                m_swUserName.setText(J_UserName);
                Editor.getInstance().getMainFrame().setChanged();
            }
        } else {
            if ((m_swUserName.getText() != null) && (m_swUserName.getText().length() > 0)) {
                m_swUserName.setText(null);
                Editor.getInstance().getMainFrame().setChanged();
            }
        }
    }

    /** User name component events management.
        Notifies content has changed. */
    private class UserActionListener implements javax.swing.event.DocumentListener {
        public void changedUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void insertUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        public void removeUpdate(javax.swing.event.DocumentEvent sw_Event) { onChange(); }
        private void onChange() {
            Editor.getInstance().getMainFrame().setChanged();
        }
    }
}

