/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** HTML transformation. */
class HtmlTransformation extends Transformation {

    /** Constructor. */
    public HtmlTransformation() {
    }

    /** Post-computation transformation handler.
        @param XML_Input XML result of the watch computation.
        @param J_OutputFileName Name of the file resulting of the transformation. null corresponds to the standard output.
        @return true if success, false otherwise.
        @see watch.Transformation#apply */
    public boolean apply(org.w3c.dom.Document XML_Input, String J_OutputFileName) {
        if (! applyXsl(XML_Input, "xml2html.xsl", J_OutputFileName)) {
            return false;
        }

        if (J_OutputFileName != null) {
            Traces.traceTransformation("HtmlTransformation.apply(): copying resources");
            if (! copyResourcesWith(J_OutputFileName)) {
                return false;
            }
        }

        return true;
    }

    /** Copy HTML resources next to the output file.
        @param J_OutputFileName Output file to copy the resources next to.
        @return true if success, false otherwise. */
    public static final boolean copyResourcesWith(String J_OutputFileName) {
        try {

            if (J_OutputFileName != null) {
                if (! PathControl.copyResource("ftvtree/ftv2blank.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2doc.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2folderclosed.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2folderopen.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2lastnode.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2link.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2mlastnode.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2mnode.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2node.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2plastnode.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2pnode.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("ftvtree/ftv2vertline.png", J_OutputFileName)) { return false; }
            }

            return true;

        } catch (Exception e) {
            Display.printStackTrace(e);
            return false;
        }
    }

}
