/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Path control toolkit class.
    Provides static methods helping in paths management.
    Input/output paths can be relative to the current input file, the installation directory... */
public final class PathControl {

    /** Input XML path control.
        @param J_InputPath Input file name.
        @return true if the input file is an XML file, false otherwise. */
    public static boolean isXml(String J_InputPath) {
        if (J_InputPath != null) {
            Traces.tracePath("PathControl.isXml() -> J_InputPath = " + J_InputPath);
            String[] arj_Split = J_InputPath.split("\\.");
            if ((arj_Split != null) && (arj_Split.length > 0)) {
                String j_Extension = arj_Split[arj_Split.length - 1];
                if (j_Extension != null) {
                    Traces.tracePath("PathControl.isXml() -> J_InputPath = " + J_InputPath + ", j_Extension = " + j_Extension);
                    if (j_Extension.equalsIgnoreCase("xml")) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    /** Output file retrieval.
        @param J_OutputPath Relative output path, from the current input file.
        @return Output file object. */
    public static final java.io.File outputFile(String J_OutputPath) {
        Traces.tracePath("PathControl.outputFile(J_OutputPath = " + J_OutputPath + ")");

        String j_OutputFilePath = J_OutputPath;
        if ((j_OutputFilePath != null) && (! new java.io.File(j_OutputFilePath).isAbsolute())) {
            j_OutputFilePath = new java.io.File(getInputFile().getParentFile(), j_OutputFilePath).getPath();
        }

        Traces.tracePath("PathControl.outputFile() -> " + j_OutputFilePath);
        if (j_OutputFilePath != null) {
            ensureDirectoryOf(new java.io.File(j_OutputFilePath));
            return new java.io.File(j_OutputFilePath);
        } else {
            return null;
        }
    }

    /** Input file retrieval.
        @return Current input file. null if no current input file. */
    public static final java.io.File getInputFile() {
        String j_InputPath = null;
        try {
            cli.Shell cli_Shell = Watch.getShell();
            cli.IODevice cli_Input = cli_Shell.getInput();
            cli.ResourceString cli_Location = cli_Input.getLocation();
            j_InputPath = cli_Location.getString(cli.ResourceString.LANG_EN).split(":")[0];
        } catch(Exception e) {
            Display.printStackTrace(e);
        }
        Traces.tracePath("PathControl.getInputFile() -> " + j_InputPath);
        return new java.io.File(j_InputPath);
    }
    /** Input location retrieval.
        @return Current input location. */
    public static final String getInputLocation() {
        String j_InputLocation = null;
        try {
            cli.Shell cli_Shell = Watch.getShell();
            cli.IODevice cli_Input = cli_Shell.getInput();
            cli.ResourceString cli_Location = cli_Input.getLocation();
            j_InputLocation = cli_Location.getString(cli.ResourceString.LANG_EN);
        } catch(Exception e) {
            Display.printStackTrace(e);
        }
        Traces.tracePath("PathControl.getInputFile() -> " + j_InputLocation);
        return j_InputLocation;
    }

    /** Resource file retrieval.
        @param J_ResourcePath Relative resource path, from the install directory.
        @return Resource file object. */
    public static final java.io.File resourceFile(String J_ResourcePath)
    throws java.io.FileNotFoundException {
        Traces.tracePath("PathControl.resourceFile(J_ResourcePath = " + J_ResourcePath + ")");

        String j_ResourceFilePath = J_ResourcePath;
        if (j_ResourceFilePath != null) {
            //if (new java.io.File(j_ResourceFilePath).exists()) {
            if (false) {
                // Nothing to do.
                Traces.tracePath("PathControl.resourceFile() -> j_ResourceFilePath = " + j_ResourceFilePath + " exists");
            } else {
                String j_InstallDir = getInstallDir();
                if (j_InstallDir != null) {
                    j_ResourceFilePath = j_InstallDir + java.io.File.separator + j_ResourceFilePath;
                    if (new java.io.File(j_ResourceFilePath).exists()) {
                        // ok, the resource file has been found
                        Traces.tracePath("PathControl.resourceFile() -> j_ResourceFilePath = " + j_ResourceFilePath + " exists");
                    } else {
                        Traces.tracePath("PathControl.resourceFile() -> j_ResourceFilePath = " + j_ResourceFilePath + " does not exist");
                        j_ResourceFilePath = null;
                    }
                }
            }
        }

        Traces.tracePath("PathControl.resourceFile() -> " + j_ResourceFilePath);
        if (j_ResourceFilePath != null) {
            return new java.io.File(j_ResourceFilePath);
        } else {
            throw new java.io.FileNotFoundException(getInputLocation() + "No such resource file '" + J_ResourcePath + "'");
        }
    }

    /** Install directory determination.
        @return Install directory path. */
    private static final String getInstallDir() {
        String j_InstallDir = null;
        String j_Property = System.getProperty("java.library.path");
        if (j_Property != null) {
            String[] arj_ClassPath = j_Property.split(";");
            for (String j_ClassPath : arj_ClassPath) {
                java.io.File j_WatchClass = new java.io.File(j_ClassPath, "watch/Watch.class");
                if ((j_WatchClass != null) && (j_WatchClass.exists())) {
                    j_InstallDir = j_ClassPath;
                }
            }
        }
        Traces.tracePath("PathControl.getInstallDir() -> " + j_InstallDir);
        return j_InstallDir;
    }

    /** Resource copying.
        @param J_ResourcePath Relative resource path, from the install directory.
        @param J_OutputPath Relative output path, from the current input file.
        @return true if success, false otherwise. */
    public static final boolean copyResource(String J_ResourcePath, String J_OutputPath) {
        Traces.tracePath("PathControl.copyResource(J_ResourcePath = " + J_ResourcePath + ", J_OutputPath = " + J_OutputPath + ")");
        try {
            if (J_OutputPath != null) {
                java.io.File j_OutputFile = outputFile(J_OutputPath);
                java.io.File j_Directory = j_OutputFile.getParentFile();

                java.io.File j_ResourceFile = resourceFile(J_ResourcePath);
                java.io.File j_CopyFile = new java.io.File(j_Directory, J_ResourcePath);
                Traces.tracePath("PathControl.copyResource() -> j_CopyFile = " + j_CopyFile);

                if (! j_CopyFile.exists()) {
                    if (! ensureDirectoryOf(j_CopyFile)) {
                        return false;
                    }

                    java.io.FileInputStream j_Source = new java.io.FileInputStream(j_ResourceFile);
                    java.io.FileOutputStream j_Copy = new java.io.FileOutputStream(j_CopyFile);
                    byte[] arb_Buffer = new byte[100];
                    while (j_Source.available() > 0) {
                        int i_Read = j_Source.read(arb_Buffer);
                        if (i_Read > 0) {
                            j_Copy.write(arb_Buffer, 0, i_Read);
                        }
                    }

                    j_Source.close();
                    j_Copy.close();
                }
            }

            return true;

        } catch (Exception e) {
            Display.printStackTrace(e);
            return false;
        }
    }

    /** XSL file retrieval.
        @param J_XslPath Path of an XSL file, either from the current input file, or from the install directory.
        @return XSL file object. */
    public static final java.io.File xslFile(String J_XslPath)
    throws java.io.FileNotFoundException {
        java.io.File j_OutputFile = outputFile(J_XslPath);
        if ((j_OutputFile != null) && (j_OutputFile.exists())) {
            Traces.tracePath("PathControl.xslFile() -> " + j_OutputFile + " (from input file)");
            return j_OutputFile;
        }
        java.io.File j_ResourceFile = resourceFile(J_XslPath);
        if ((j_ResourceFile != null) && (j_ResourceFile.exists())) {
            Traces.tracePath("PathControl.xslFile() -> " + j_ResourceFile + " (from install directory)");
            return j_ResourceFile;
        }
        Traces.tracePath("PathControl.xslFile() -> " + null);
        return null;
    }

    /** Directory checking.
        @param J_Path Output file whose path needs directory checking.
        @return true if success, false otherwise. */
    private static final boolean ensureDirectoryOf(java.io.File J_Path) {
        try {
            Traces.tracePath("PathControl.ensureDirectoryOf(J_Path = " + J_Path + ")");

            java.io.File j_Directory = J_Path.getParentFile();
            if (j_Directory == null) {
                // No parent path name => current directory.
                return true;
            } else if (j_Directory.exists()) {
                if (j_Directory.isDirectory()) {
                    return true;
                }
            } else {
                if (j_Directory.mkdirs()) {
                    return true;
                }
            }
            return false;
        } catch (Exception e) {
            Display.printStackTrace(e);
            return false;
        }
    }

}
