/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Timeplot transformation.
    Creates graphs using the timpeplot library.
    This transformation creates en HTML doc and copies the timeplot resources next to it. */
class TimeplotTransformation extends Transformation {

    /** Constructor. */
    public TimeplotTransformation() {
    }

    /** Post-computation transformation handler.
        Launches two XSl transformation: one for the HTML page creation, and another one for the data creation.
        Then copies the resources next to the output file.
        @param XML_Input XML result of the watch computation.
        @param J_OutputFileName Name of the file resulting of the transformation.
        @return true if success, false otherwise. */
    public boolean apply(org.w3c.dom.Document XML_Input, String J_OutputFileName) {
        if (! applyXsl(XML_Input, "xml2timeplot_html.xsl", J_OutputFileName)) {
            return false;
        }
        if (! applyXsl(XML_Input, "xml2timeplot_data.xsl", J_OutputFileName + ".txt")) {
            return false;
        }

        if (J_OutputFileName != null) {
            Traces.traceTransformation("TimeplotTransformation.apply(): copying resources");
            if (! copyResourcesWith(J_OutputFileName)) {
                return false;
            }
        }

        return true;
    }

    /** Copy timeplot resources next to the output file.
        @param J_OutputFileName Output file to copy the resources next to.
        @return true if success, false otherwise. */
    public static final boolean copyResourcesWith(String J_OutputFileName) {
        try {

            if (J_OutputFileName != null) {
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/content/history.html", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-bottom-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-bottom-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-bottom-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-bottom.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-left-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-right-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-top-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-top-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-top-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/bubble-top.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/close-button.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/copy.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-bottom-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-bottom-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-top-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/images/message-top-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/ajax.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/data-structure.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/date-time.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/debug.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/dom.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/graphics.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/history.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/html.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/jquery-1.2.3.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/json.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/platform.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/signal.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/string.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/units.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/window-manager.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/scripts/xmlhttp.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/simile-ajax-api.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/ajax/api-2.0/simile-ajax-bundle.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/robots.txt", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/geochrono-api.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/scripts/ether-painters.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/scripts/geochrono.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/scripts/l10n/en/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/scripts/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/geochrono/scripts/units.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/planning-api.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/scripts/ether-painters.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/scripts/l10n/en/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/scripts/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/scripts/planning.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/ext/planning/scripts/units.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/blue-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-bottom-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-bottom-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-bottom-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-bottom.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-left-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-right-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-top-arrow.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-top-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-top-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/bubble-top.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/close-button.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/copyright-vertical.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/copyright.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dark-blue-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dark-green-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dark-red-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dull-blue-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dull-green-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/dull-red-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/gray-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/green-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-bottom-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-bottom-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-top-left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/message-top-right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/progress-running.gif", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/red-circle.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/images/top-bubble.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/decorators.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/detailed-painter.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/ether-painters.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/ethers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/ext/japanese-eras.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/cs/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/cs/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/de/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/de/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/en/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/en/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/es/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/es/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/fr/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/fr/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/it/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/it/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/ru/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/ru/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/se/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/se/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/tr/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/tr/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/vi/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/vi/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/zh/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/l10n/zh/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/labellers.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/original-painter.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/overview-painter.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/sources.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/themes.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/timeline.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/scripts/units.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/styles/ethers.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/styles/events.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/styles/timeline.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/timeline-api.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/timeline-bundle.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeline/api-2.0/timeline-bundle.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/images/copyright.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/images/line_left.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/images/line_right.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/images/progress-running.gif", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/index.html", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/excanvas.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/errorIcon.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/firebug.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/firebug.html", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/firebug.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/firebugx.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/infoIcon.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/lib/firebug/warningIcon.png", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/color.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/geometry.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/math.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/plot.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/processor.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/sources.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/scripts/timeplot.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/styles/timeplot.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/timeplot-api.js", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/timeplot-bundle.css", J_OutputFileName)) { return false; }
                if (! PathControl.copyResource("static.simile.mit.edu/timeplot/api/1.0/timeplot-bundle.js", J_OutputFileName)) { return false; }
            }

            return true;

        } catch (Exception e) {
            Display.printStackTrace(e);
            return false;
        }
    }

}
