/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** Traces management class. */
class Traces {

    /** Returns a string giving all watch trace classes.
        @return String giving all watch trace classes. */
    public static final String getClasses() {
        return (
            WATCH_APP.getClassName() + ","
            + WATCH_INPUT.getClassName() +","
            + WATCH_COMPUTATION.getClassName() + ","
            + WATCH_TRANSFORMATION.getClassName() + ","
            + WATCH_PATH.getClassName() + ","
            + WATCH_PERF.getClassName()
        );
    }

    /** WATCH_APP trace class.
        Enables traces describing the application execution.
        @see watch.Watch#main */
    public static final cli.TraceClass WATCH_APP = new cli.TraceClass("WATCH_APP",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application main traces")
                        .addHelp(cli.Help.LANG_FR, "Traces principales de l'application Watch"));
    /** WATCH_APP trace method.
        @param J_Trace Trace message. */
    public static final void traceApp(String J_Trace) {
        trace(WATCH_APP, J_Trace);
    }

    /** WATCH_INPUT trace class.
        Enables traces regarding the CLI commands in input.
        @see watch.Watch */
    public static final cli.TraceClass WATCH_INPUT = new cli.TraceClass("WATCH_INPUT",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application CLI input commands traces")
                        .addHelp(cli.Help.LANG_FR, "Traces des commandes d'entre CLI de l'application Watch"));
    /** WATCH_INPUT trace method.
        @param J_Trace Trace message. */
    public static final void traceInput(String J_Trace) {
        trace(WATCH_INPUT, J_Trace);
    }

    /** WATCH_COMPUTATION trace class.
        Enables traces regarding the computation.
        @see watch.Watch#execute */
    public static final cli.TraceClass WATCH_COMPUTATION = new cli.TraceClass("WATCH_COMPUTATION",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application intermediate computation traces")
                        .addHelp(cli.Help.LANG_FR, "Traces des rsultats intermdiaires de calculs de l'application Watch"));
    /** WATCH_COMPUTATION trace method.
        @param J_Trace Trace message. */
    public static final void traceComputation(String J_Trace) {
        trace(WATCH_COMPUTATION, J_Trace);
    }

    /** WATCH_TRANSFORMATION trace class.
        Enables traces regarding the post-computation transformation.
        @see watch.Transformation */
    public static final cli.TraceClass WATCH_TRANSFORMATION = new cli.TraceClass("WATCH_TRANSFORMATION",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application results transformation traces")
                        .addHelp(cli.Help.LANG_FR, "Traces de transformations de rsultats de l'application Watch"));
    /** WATCH_TRANSFORMATION trace method.
        @param J_Trace Trace message. */
    public static final void traceTransformation(String J_Trace) {
        trace(WATCH_TRANSFORMATION, J_Trace);
    }

    /** WATCH_PATH trace class.
        Enables traces regarding the input and output paths management.
        @see watch.PathControl */
    public static final cli.TraceClass WATCH_PATH = new cli.TraceClass("WATCH_PATH",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application file path control traces")
                        .addHelp(cli.Help.LANG_FR, "Traces de contrle de chemin de fichier de l'application Watch"));
    /** WATCH_PATH trace method.
        @param J_Trace Trace message. */
    public static final void tracePath(String J_Trace) {
        trace(WATCH_PATH, J_Trace);
    }

    /** WATCH_PERF trace class.
        Enables traces regarding the performances.*/
    public static final cli.TraceClass WATCH_PERF = new cli.TraceClass("WATCH_PERF",
        new cli.Help()  .addHelp(cli.Help.LANG_EN, "Watch application performance traces")
                        .addHelp(cli.Help.LANG_FR, "Traces de performances de l'application Watch"));
    /** WATCH_PERF trace method.
        @param J_Trace Trace message. */
    public static final void tracePerf(String J_Trace) {
        trace(WATCH_PERF, J_Trace);
    }

    /** Trace filter configuration.
        @param J_TraceClass Trace class to configure.
        @param B_ShowTraces true if the traces of the given trace class should be displayed, false otherwise. */
    public static final void showTraces(String J_TraceClass, boolean B_ShowTraces) {
        if (J_TraceClass != null) {
            cli.Traces.setFilter(new cli.TraceClass(J_TraceClass, new cli.Help()), B_ShowTraces);
        }
    }
    private static final void trace(cli.TraceClass CLI_TraceClass, String J_Trace) {
        if (J_Trace != null) {
            cli.Traces.trace(CLI_TraceClass, J_Trace);
        }
    }

}
