/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** User model class. */
class User {

    /** User map class */
    public static class Map extends java.util.TreeMap<String, User> {
        /** Constructor. */
        public Map() {
        }

        /** Ensures a given user is present in the user database.
            @param J_UserName User name to ensure.
            @return The user object instance already registered if set, the new user object registered otherwise. */
        public User ensure(String J_UserName) {
            User w_UserRes = null;
            if (this.containsKey(J_UserName)) {
                w_UserRes = this.get(J_UserName);
            } else {
                w_UserRes = new User(J_UserName);
                this.put(J_UserName, w_UserRes);
                Traces.traceInput("New user = " + w_UserRes);
            }
            return w_UserRes;
        }

        /** Returns a user instance list corresponding to the given user names.
            @param J_Users List of user names researched.
            @return Map of user instances indexed by the user names. */
        public User.Map getListOf(java.util.Collection<String> J_Users) {
            User.Map w_List = new User.Map();
            if (J_Users != null) {
                for (java.util.Iterator<String> j_It = J_Users.iterator(); j_It.hasNext(); ) {
                    String j_UserName = j_It.next();
                    if (this.containsKey(j_UserName)) {
                        w_List.put(j_UserName, this.get(j_UserName));
                    } else {
                        Display.error("No such user '" + j_UserName + "'");
                    }
                }
                if ((! J_Users.isEmpty()) && (w_List.isEmpty())) {
                    Display.warn("No user focus");
                }
            }
            return w_List;
        }

        /** Native string convertion.
            @return String representation. */
        public String toString() {
            String j_Res = "";
            for (java.util.Iterator<String> j_It = this.keySet().iterator(); j_It.hasNext(); ) {
                String j_UserName = j_It.next();
                if (j_UserName != null) {
                    if (j_Res.length() > 0) {
                        j_Res += ", ";
                    }
                    j_Res += j_UserName;
                }
            }
            return j_Res;
        }
    }

    /** Constructor.
        @param J_UserName User identifier: either the full name, or initials... whatever, it is up to the user to choose. */
    public User(String J_UserName) {
        m_jUserName = new String(J_UserName);
    }

    /** User name accessor.
        @return The name of the user. */
    public String getName() {
        return new String(m_jUserName);
    }

    /** String representation of the object.
        @return String representation of the object. */
    public String toString() {
        return ("User '" + getName() + "'");
    }

    private final String m_jUserName;

}
