/*
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package watch;


/** User-defined XSL output transformation class. */
class XslTransformation extends Transformation {

    /** Constructor.
        @param J_XslFileName User defined XSL stylesheet file name. */
    public XslTransformation(String J_XslFileName) {
        m_jXslFileName = new String(J_XslFileName);
    }

    /** User-defined XSL transformation application.
        @param W_Input Input XML document representative of the Watch computation.
        @param J_OutputFileName Output file name.
        @return true if success, false otherwise. */
    public boolean apply(org.w3c.dom.Document W_Input, String J_OutputFileName) {
        if (! applyXsl(W_Input, m_jXslFileName, J_OutputFileName)) {
            return false;
        }

        // By default, let's copy all possible resources.
        Traces.traceTransformation("XslTransformation.apply(): copying HTML resources");
        if (! HtmlTransformation.copyResourcesWith(J_OutputFileName)) {
            return false;
        }
        Traces.traceTransformation("XslTransformation.apply(): copying Timeplot resources");
        if (! TimeplotTransformation.copyResourcesWith(J_OutputFileName)) {
            return false;
        }

        return true;
    }

    private final String m_jXslFileName;
}
