<?xml version="1.0" encoding="iso-8859-1"?>

<!--
    Copyright (c) 2008-2010, Alexis Royer, http://alexis.royer.free.fr/Watch

    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

        * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
        * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
        * Neither the name of the Watch project nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
    LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
    NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-->

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:tp="timeplot">
<xsl:output method="text" encoding="iso-8859-1" indent="yes"/>

<xsl:param name="B_EVM">
    <xsl:choose>
    <!-- @planned attributes are always in the output, always nul however if useless -->
    <xsl:when test="sum(/watch/task/@planned) &gt; 0">1</xsl:when>
    <xsl:otherwise>0</xsl:otherwise>
    </xsl:choose>
</xsl:param>

<xsl:variable name="STR_Endl"><xsl:text>
</xsl:text></xsl:variable>

<xsl:template match="/watch">
    <text>
    <xsl:text>#</xsl:text><xsl:value-of select="$STR_Endl"/>
    <xsl:text># File generated by Watch (c) (alexis.royer@gmail.com)</xsl:text><xsl:value-of select="$STR_Endl"/>
    <xsl:text># History of project </xsl:text><xsl:value-of select="@project"/><xsl:value-of select="$STR_Endl"/>
    <xsl:text>#</xsl:text><xsl:value-of select="$STR_Endl"/>
    <xsl:value-of select="$STR_Endl"/>

    <xsl:text># date(8601), reference, imputed, reviewed, reviewed + risks, reviewed - opportunities</xsl:text>
    <xsl:if test="$B_EVM = 1"><xsl:text>, BAC, BCWS, BCWP, ACWP, SPI, CPI, EAC</xsl:text></xsl:if>
    <xsl:value-of select="$STR_Endl"/>
    <xsl:text># ------------------------------------------------------------------------------------</xsl:text>
    <xsl:if test="$B_EVM = 1"><xsl:text>--------------------------------------</xsl:text></xsl:if>
    <xsl:value-of select="$STR_Endl"/>

    <xsl:apply-templates select="*"/>
    </text>
</xsl:template>

<xsl:template match="task">
    <xsl:if test="@date">
        <!-- Date -->
        <xsl:call-template name="T_Mk8601">
            <xsl:with-param name="STR_Date" select="@date"/>
        </xsl:call-template>
        <xsl:text>,</xsl:text>

        <!-- Reference value -->
        <xsl:value-of select="0 + @reference"/>
        <xsl:text>,</xsl:text>

        <!-- Imputed value -->
        <xsl:value-of select="0 + @imputed"/>
        <xsl:text>,</xsl:text>

        <!-- Reviewed value -->
        <xsl:value-of select="0 + @imputed + @remaining"/>
        <xsl:text>,</xsl:text>

        <!-- Reviewed value + risks -->
        <xsl:value-of select="0 + @imputed + @remaining + @remaining-risks"/>
        <xsl:text>,</xsl:text>

        <!-- Reviewed value - opportunities -->
        <xsl:value-of select="0 + @imputed + @remaining - @remaining-opportunities"/>

        <!-- Earn Value Management -->
        <xsl:if test="$B_EVM = 1">
            <!-- BAC (Budgeted At Completion) -->
            <xsl:variable name="BAC" select="number(@reference)"/>
            <!-- BCWS (Budgeted Cost of Work Scheduled) -->
            <xsl:variable name="BCWS" select="number(@planned)"/>
            <!-- BCWP (Budgeted Cost of Work Performed) -->
            <xsl:variable name="BCWP" select="number(@earned)"/>
            <!-- ACWP (Actual Cost of Work Performed) -->
            <xsl:variable name="ACWP" select="number(@imputed)"/>
            <!-- CV (Cost Variance) -->
            <xsl:variable name="CV" select="$BCWP - $ACWP"/>
            <!-- CVP (Cost Variance Percentage) -->
            <xsl:variable name="CVP" select="$CV div $BCWP"/>
            <!-- SV (Schedule Variance) -->
            <xsl:variable name="SV" select="$BCWP - $BCWS"/>
            <!-- SVP (Schedule Variance Percentage) -->
            <xsl:variable name="SVP" select="$SV div $BCWS"/>
            <!-- CPI (Cost Performance Index) = BCWP / ACWP -->
            <xsl:variable name="CPI" select="$BCWP div $ACWP"/>
            <!-- SPI (Schedule Performance Index) = BCWP / BCWS -->
            <xsl:variable name="SPI" select="$BCWP div $BCWS"/>
            <!-- EAC (Estimated At Completion) = BAC * ACWP / BCWP -->
            <xsl:variable name="EAC">
                <xsl:choose>
                <xsl:when test="$BCWP = 0"><xsl:value-of select="$BAC"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="$BAC * $ACWP div $BCWP"/></xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="EAC2" select="($EAC * $BCWS div $BAC) + ($BAC - $BCWS)"/>

            <!-- BAC -->    <xsl:text>,</xsl:text>  <xsl:value-of select="$BAC"/>
            <!-- BCWS -->   <xsl:text>,</xsl:text>  <xsl:value-of select="$BCWS"/>
            <!-- BCWP -->   <xsl:text>,</xsl:text>  <xsl:value-of select="$BCWP"/>
            <!-- ACWP -->   <xsl:text>,</xsl:text>  <xsl:value-of select="$ACWP"/>
            <!-- SPI -->    <xsl:text>,</xsl:text>  <xsl:value-of select="$SPI"/>
            <!-- CPI -->    <xsl:text>,</xsl:text>  <xsl:value-of select="$CPI"/>
            <!-- EAC -->    <xsl:text>,</xsl:text>  <xsl:value-of select="$EAC2"/>
        </xsl:if>

        <!-- End of line -->
        <xsl:value-of select="$STR_Endl"/>
    </xsl:if>
</xsl:template>

<xsl:template name="T_Mk8601">
    <xsl:param name="STR_Date" select="'2000-12-31'"/>

    <xsl:choose>
    <xsl:when test="/watch/@sample-date = '2000-12-31'">
        <xsl:value-of select="$STR_Date"/>
    </xsl:when>
    <xsl:when test="(/watch/@sample-date = '12/31/2000') or (/watch/@sample-date = '12/31/00')">
        <xsl:variable name="str_Month">
            <xsl:call-template name="T_Mk2Digits">
                <xsl:with-param name="STR_Value" select="substring-before($STR_Date,'/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="str_DayYear" select="substring-after($STR_Date,'/')"/>

        <xsl:variable name="str_Day">
            <xsl:call-template name="T_Mk2Digits">
                <xsl:with-param name="STR_Value" select="substring-before($str_DayYear,'/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="str_Year">
            <xsl:call-template name="T_MkYear">
                <xsl:with-param name="N_Year" select="substring-after($str_DayYear, '/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:value-of select="$str_Year"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="$str_Month"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="$str_Day"/>
    </xsl:when>
    <xsl:when test="(/watch/@sample-date = '31/12/2000') or (/watch/@sample-date = '31/12/00')">
        <xsl:variable name="str_Day">
            <xsl:call-template name="T_Mk2Digits">
                <xsl:with-param name="STR_Value" select="substring-before($STR_Date,'/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="str_MonthYear" select="substring-after($STR_Date,'/')"/>

        <xsl:variable name="str_Month">
            <xsl:call-template name="T_Mk2Digits">
                <xsl:with-param name="STR_Value" select="substring-before($str_MonthYear,'/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="str_Year">
            <xsl:call-template name="T_MkYear">
                <xsl:with-param name="N_Year" select="substring-after($str_MonthYear, '/')"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:value-of select="$str_Year"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="$str_Month"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="$str_Day"/>
    </xsl:when>
    </xsl:choose>

</xsl:template>

<xsl:template name="T_Mk2Digits">
    <xsl:param name="STR_Value" select="''"/>

    <xsl:choose>
    <xsl:when test="string-length($STR_Value) &lt; 2">
        <xsl:call-template name="T_Mk2Digits">
            <xsl:with-param name="STR_Value">0<xsl:value-of select="$STR_Value"/></xsl:with-param>
        </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
        <xsl:value-of select="$STR_Value"/>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name="T_MkYear">
    <xsl:param name="N_Year" select="1970"/>

    <xsl:choose>
    <xsl:when test="$N_Year &gt; 99">
        <xsl:value-of select="$N_Year"/>
    </xsl:when>
    <xsl:when test="$N_Year &gt; 70">
        <xsl:text>19</xsl:text>
        <xsl:value-of select="$N_Year"/>
    </xsl:when>
    <xsl:otherwise>
        <xsl:text>20</xsl:text>
        <xsl:call-template name="T_Mk2Digits">
            <xsl:with-param name="STR_Value" select="$N_Year"/>
        </xsl:call-template>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="*"/>

</xsl:stylesheet>
